@@ -2,8 +2,10 @@ import os
 import numpy as np
 import json
 import torch
+from torch import nn
 from torch.utils.data import Dataset, DataLoader
-from transformers import BertTokenizerFast
+from transformers import BertModel, BertTokenizerFast
+from .model import GlobalPointer
 from .utils import rematch
 
 __all__=['load_NNER']
@@ -29,6 +31,21 @@ class _CustomDataset4test(Dataset):
 
         return enc_context
 
+class GlobalPointerNet(nn.Module):
+    def __init__(self, model_name, c_size=9, head_size=64, embedding_size=1024):
+        super(GlobalPointerNet, self).__init__()
+        self.head = GlobalPointer(c_size, head_size, embedding_size)
+        self.bert = BertModel.from_pretrained(model_name)
+
+    def forward(self, input_ids, attention_mask, token_type_ids):
+        x1 = self.bert(input_ids, attention_mask=attention_mask, token_type_ids=token_type_ids)
+        x2 = x1.last_hidden_state
+        #last_hidden_state (torch.FloatTensor of shape (batch_size, sequence_length, hidden_size))
+        # – Sequence of hidden-states at the output of the last layer of the model.
+
+        logits = self.head(x2, mask=attention_mask)
+        return logits
+
 class _NamedEntityRecognizer(object):
     """
     命名实体识别器
